==> improviser-0.5.6.4.tar.gz: improviser-0.5.6.4/improviser/Bands.py <==
from Musicians import *

"""

	Possible instrument parameters:

		channel		=	MIDI channel
		min_velocity	=	Minimum volume [0-128]
		max_velocity	=	Maximum volume [0-128]
		chance		~= 	Chance to play on tick
		end		 = 	Iteration to end on, default: 0
		start		 = 	Iteration to start on, default: 0
		step 		=	Iterations to wait after end



"""


dummy_parameters = {'channel': 1}

dummy = [
	#SimpleChordInstrument({'channel': 1, 'start': 16}), 
	SlowStridePianist({'max_velocity': 80, 'start': 0, 'step': 2 }),
	FastStridePianist({'max_velocity': 80, 'start': 2, 'step': 2}),
	RockDrum({'start': 0}),
	#JazzDrum({'start': 8, 'end': 12}), 
	BassInstrument({'channel':1, 'start': 1}),
	ChordInstrument({'channel':7, 'chance': 0.15, \
			 'max_velocity': 70, 'start': 2}), 
	SoloInstrument({'channel':1, 'start': 4, 'end': 8, 'chance': 0.2, 
			'step': 4}),
	SoloInstrument({'channel':11, 'start': 8, 'end': 12, 'step':2}),
	SoloInstrument({'channel':12, 'start': 4, 'end': 8, 'step':4}),
	SoloInstrument({'channel':7, 'start': 16, 'end': 20, 'step': 4})
	 ]

swing = [
	ChordInstrument({'channel':7, 'chance': 0.15, 'max_velocity': 70}), 
	SlowStridePianist({'max_velocity': 80}),
	RockDrum({'start': 0}),
	SoloInstrument({'channel':11}),
	]

boogie = [
	BoogieWoogieRhythm({'channel': 1}),
	RockDrum({}),
	SoloInstrument({'channel':11}),
	]

metal = [
	BlastBeat({'max_velocity': 80}),
	PowerChords({'channel': 7, 'midi_instr': 30}),
	SoloInstrument({'channel':6, 'midi_instr': 32}),
	]

jazz = [
	SoloInstrument({'channel': 11, 'start': 2, 'step': 4}),
	SoloInstrument({'channel': 15, 'start': 6, 'stop': 8, 'step': 4, 'max_velocity': 80}),
	ChordInstrument({'channel': 4, 'max_velocity': 70, 'chance': 0.5, 'start': 4}),
	BassInstrument({'channel': 6, 'start': 3}),
	SlowStridePianist({'channel': 3, 'start':0, 'step': 4, 'max_velocity': 70}),
	FastStridePianist({'channel': 3, 'start':4, 'step': 4}),
	SimpleChordInstrument({'channel': 1}),
	RockDrum({'start': 4}),
	]

==> improviser-0.5.6.5.tar.gz: improviser-0.5.6.5/improviser/Bands.py <==
from Musicians import *

"""

	Possible instrument parameters:

		channel		=	MIDI channel
		min_velocity	=	Minimum volume [0-128]
		max_velocity	=	Maximum volume [0-128]
		chance		~= 	Chance to play on tick
		end		 = 	Iteration to end on, default: 0
		start		 = 	Iteration to start on, default: 0
		step 		=	Iterations to wait after end



"""


dummy_parameters = {'channel': 1}

dummy = [
	#SimpleChordInstrument({'channel': 1, 'start': 16}), 
	SlowStridePianist({'max_velocity': 80, 'start': 0, 'step': 2 }),
	FastStridePianist({'max_velocity': 80, 'start': 2, 'step': 2}),
	RockDrum({'start': 0}),
	#JazzDrum({'start': 8, 'end': 12}), 
	BassInstrument({'channel':1, 'start': 1}),
	ChordInstrument({'channel':7, 'chance': 0.15, \
			 'max_velocity': 70, 'start': 2}), 
	SoloInstrument({'channel':1, 'start': 4, 'end': 8, 'chance': 0.2, 
			'step': 4}),
	SoloInstrument({'channel':11, 'start': 8, 'end': 12, 'step':2}),
	SoloInstrument({'channel':12, 'start': 4, 'end': 8, 'step':4}),
	SoloInstrument({'channel':7, 'start': 16, 'end': 20, 'step': 4})
	 ]

swing = [
	ChordInstrument({'channel':7, 'chance': 0.15, 'max_velocity': 70}), 
	SlowStridePianist({'max_velocity': 80}),
	RockDrum({'start': 0}),
	SoloInstrument({'channel':11}),
	]

boogie = [
	BoogieWoogieRhythm({'channel': 1}),
	RockDrum({}),
	SoloInstrument({'channel':11}),
	]

metal = [
	BlastBeat({'max_velocity': 80}),
	PowerChords({'channel': 7, 'midi_instr': 30}),
	SoloInstrument({'channel':6, 'midi_instr': 32}),
	BassInstrument({'channel':5, 'midi_instr':36}),
	]

jazz = [
	SoloInstrument({'midi_instr': 11, 'channel': 11, 'start': 0, 'step': 4}),
	SoloInstrument({'midi_instr': 57,'channel': 15, 'start': 4, 'stop': 8, 'step': 4, 'max_velocity': 80}),
	BassInstrument({'channel': 2, 'start': 0, 'let_ring': True}),
	SlowStridePianist({'channel': 3, 'start':0, 'step': 4, 'max_velocity': 70}),
	FastStridePianist({'channel': 5, 'start':4, 'step': 4}),
	ChordInstrument({'channel': 4, 'max_velocity': 70, 'chance': 0.5, 'start': 4, 'midi_instr': 1}),
	SimpleChordInstrument({'channel': 1}),
	RockDrum({}),
	]
